/*
 * [ZipnameContext.java]
 *
 * Summary: Different contexts for a Zip File to have a name.
 *
 * Copyright: (c) 2009-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2007-07-16 Created with IntelliJ IDEA.
 */
package com.mindprod.replicatorcommon;

import java.io.Serializable;

/**
 * Different contexts for a Zip File to have a name.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2007-07-16 Created with IntelliJ IDEA.
 * @since 2009
 */
public enum ZipnameContext implements Serializable
    {
        /**
         * Where-code to request filename on source machine.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) ON_SOURCE,
        /**
         * Where-code to request filename on target client machine.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) ON_TARGET,
        /**
         * Where-code to request URL on website.
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) ON_WEBSITE,
        /**
         * Can't make this into an enum without incompatible user receiver.ser file. where-code relative to
         * RECEIVER_ZIP-URL (usually WEBSITE, but possibly LAN URL )
         */
        @SuppressWarnings( { "EnumeratedConstantNamingConvention" } ) ON_RECEIVER_ZIP_URL,
        /**
         * where-code to request relative to base directory
         */
        RELATIVE;

    /**
     * Layout version number.
     */
    private static final long serialVersionUID = 370L;
    }
